@@ -2620,7 +2620,7 @@ install_method (OOP methodOOP)
 
 #ifdef USE_JIT_TRANSLATION
   if (oldMethod != _gst_nil_oop)
-    discard_native_code (oldMethod);
+    _gst_discard_native_code (oldMethod);
 #endif
 
   _gst_invalidate_method_cache ();
@@ -2810,25 +2810,6 @@ _gst_compiled_method_at_put (OOP methodOOP,
   OOP_TO_OBJ (method->literals)->data[index - 1] = valueOOP;
 }
 
-OOP
-_gst_get_method_descriptor (OOP methodOOP)
-{
-  gst_compiled_method method;
-
-  method = (gst_compiled_method) OOP_TO_OBJ (methodOOP);
-  return (method->descriptor);
-}
-
-void
-_gst_set_method_descriptor (OOP methodOOP,
-			    OOP descriptorOOP)
-{
-  gst_compiled_method method;
-
-  method = (gst_compiled_method) OOP_TO_OBJ (methodOOP);
-  method->descriptor = descriptorOOP;
-}
-
 OOP
 method_info_new (OOP class,
 		 OOP selector)
