@@ -405,7 +405,7 @@ static const class_definition class_info[] = {
    "HashedCollection", "tally", NULL, NULL },
 
   {&_gst_set_class, &_gst_hashed_collection_class,
-   true, false, true, 1,
+   true, false, true, 0,
    "Set", NULL, NULL, NULL },
 
   {&_gst_identity_set_class, &_gst_set_class,
@@ -1142,6 +1142,8 @@ _gst_init_dictionary_on_image_load (long numOOPs)
         _gst_restore_cfunc_descriptor (oop); /* in cint.c */
       else if UNCOMMON (OOP_CLASS (oop) == _gst_compiled_method_class)
         _gst_restore_primitive_number (oop, primitive_numbers_map);
+      else if UNCOMMON (OOP_CLASS (oop) == _gst_callin_process_class)
+        _gst_terminate_process (oop);
     }
 
   return (true);
