@@ -191,7 +191,7 @@ enum {
 
 /* Answer whether an object, OOP, is readonly. */
 #define IS_OOP_READONLY(oop) \
-  (((oop)->flags & F_READONLY) != 0)
+  (IS_INT((oop)) ? true : ((oop)->flags & F_READONLY) != 0)
 
 /* Set whether an object, OOP, is readonly or readwrite. */
 #define MAKE_OOP_READONLY(oop, ro) do { \
