@@ -28,25 +28,8 @@
  *
  ***********************************************************************/
 
-#include "gst.h"
 #include "gstpriv.h"
 
-#include <sys/types.h>
-#include <poll.h>
-#include <errno.h>
-#include <stdio.h>
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#ifdef STDC_HEADERS
-# include <string.h>
-# include <stdlib.h>
-#endif /* STDC_HEADERS */
-
-#include <stdarg.h>
-
 #ifdef HAVE_READLINE
 # include <readline/readline.h>
 # include <readline/history.h>
@@ -336,8 +319,13 @@ my_getc (input_stream stream)
   switch (stream->type)
     {
     case STREAM_STRING:
-      ic = (unsigned char) *stream->st_str.str++;
-      return ((ic == '\0') ? EOF : ic);
+      ic = (unsigned char) *stream->st_str.str;
+      if (!ic)
+	return EOF;
+      else
+	stream->st_str.str++;
+
+      return ic;
 
     case STREAM_OOP:
       /* Refill the buffer... */
@@ -806,7 +794,8 @@ _gst_next_char (void)
 void
 _gst_unread_char (int ic)
 {
-  in_stream->pushedBackChars[in_stream->pushedBackCount++] = ic;
+  if (ic != EOF)
+    in_stream->pushedBackChars[in_stream->pushedBackCount++] = ic;
 }
 
 
@@ -1102,8 +1091,8 @@ readline_match_symbols (char *text,
     }
 
   matches_left = high - current_index;
-  return matches_left ? completion_matches (text,
-					    symbol_generator) : NULL;
+  return matches_left ? rl_completion_matches (text,
+					       symbol_generator) : NULL;
 }
 
 int
