@@ -364,9 +364,6 @@ static void sync_signal (OOP semaphoreOOP);
 /* Suspend execution of PROCESSOOP.  */
 static void suspend_process (OOP processOOP);
 
-/* Terminate execution of the given PROCESSOOP.  */
-static void terminate_process (OOP processOOP);
-
 /* Resume execution of PROCESSOOP.  If it must preempt the currently
    running process, or if ALWAYSPREEMPT is true, put to sleep the
    active process and activate PROCESSOOP instead; if it must not,
@@ -1407,7 +1404,7 @@ suspend_process (OOP processOOP)
 }
 
 void
-terminate_process (OOP processOOP)
+_gst_terminate_process (OOP processOOP)
 {
   gst_process process;
 
@@ -1954,7 +1951,7 @@ _gst_init_interpreter (void)
   unsigned int i;
 
 #ifdef USE_JIT_TRANSLATION
-  init_translator ();
+  _gst_init_translator ();
   ip = 0;
 #else
   ip = NULL;
@@ -2108,6 +2105,14 @@ _gst_invalidate_method_cache (void)
 {
   int i;
 
+#ifdef USE_JIT_TRANSLATION
+  /* Only run this if code was run since the last method cache cleanup.  */
+  if (_gst_sample_counter)
+    _gst_reset_inline_caches ();
+#else
+  at_cache_class = at_put_cache_class = size_cache_class = NULL;
+#endif
+
   _gst_cache_misses = _gst_sample_counter = 0;
 
   for (i = 0; i < METHOD_CACHE_SIZE; i++)
@@ -2118,9 +2123,6 @@ _gst_invalidate_method_cache (void)
 #endif
     }
 
-#ifndef USE_JIT_TRANSLATION
-  at_cache_class = at_put_cache_class = size_cache_class = NULL;
-#endif
 }
 
 
@@ -2283,9 +2285,6 @@ _gst_init_signals (void)
     {
 #ifdef USE_JIT_TRANSLATION
       _gst_set_signal_handler (SIGILL, interrupt_handler);
-#endif
-#ifdef SIGBUS
-      _gst_set_signal_handler (SIGBUS, interrupt_handler);
 #endif
       _gst_set_signal_handler (SIGABRT, interrupt_handler);
     }
