@@ -392,6 +392,9 @@ extern void _gst_show_stack_contents (void);
    are actually freed. */
 extern void _gst_validate_method_cache_entries (void);
 
+/* Terminate execution of the given PROCESSOOP.  */
+extern void _gst_terminate_process (OOP processOOP);
+
 /* Similar to _gst_send_message_internal, but forces the specified
    CompiledMethod to be sent.  If it is not valid for the current
    receiver, well, you are looking for trouble and well deserve it.
