@@ -513,20 +513,6 @@ _gst_init_builtin_objects_classes (void)
     _gst_char_object_table[i].objClass = _gst_char_class;
 }
 
-void
-_gst_fixup_metaclass_objects (void)
-{
-  OOP oop;
-  mst_Object object;
-
-  for (oop = _gst_mem.ot;
-       oop <= _gst_mem.last_allocated_oop; oop++)
-    {
-      object = OOP_TO_OBJ (oop);
-      if (IS_OOP_VALID (oop) && IS_NIL (object->objClass))
-	object->objClass = _gst_metaclass_class;
-    }
-}
 
 OOP
 _gst_find_an_instance (OOP class_oop)
@@ -1173,7 +1159,7 @@ finished_incremental_gc (void)
 #ifdef USE_JIT_TRANSLATION
   /* Go and really free the blocks associated to garbage collected
      native code. */
-  free_released_native_code ();
+  _gst_free_released_native_code ();
 #endif
 }
 
@@ -1226,7 +1212,7 @@ reset_incremental_gc (OOP firstOOP)
             /* Reachable, but not referenced by active contexts.  We
                give it a second chance... */
             if (oop->flags & F_XLAT_2NDCHANCE)
-              release_native_code (oop);
+              _gst_release_native_code (oop);
 
             oop->flags ^= F_XLAT_2NDCHANCE;
           }
@@ -1284,7 +1270,7 @@ _gst_sweep_oop (OOP oop)
        method could use the same OOP as this one and the
        old method one would be executed instead of the new
        one! */
-    release_native_code (oop);
+    _gst_release_native_code (oop);
 #endif
 
   if UNCOMMON (oop->flags & F_WEAK)
@@ -1741,17 +1727,27 @@ cheney_scan (void)
   while (_gst_mem.scan.queue_at !=
 	   _gst_mem.tenuring_queue.allocPtr)
     {
-      OOP oop = *_gst_mem.scan.queue_at;
+      OOP oop;
       int i, numFields;
 
+      if (_gst_mem.scan.queue_at >= _gst_mem.tenuring_queue.topPtr)
+        _gst_mem.scan.queue_at = _gst_mem.tenuring_queue.minPtr;
+
+      if (_gst_mem.scan.queue_at == _gst_mem.tenuring_queue.allocPtr)
+	break;
+
+      oop = *_gst_mem.scan.queue_at;
+
 #if defined(GC_DEBUGGING)
+      if (!IS_OOP_ADDR (oop))
+	abort();
+
       printf (">Scan ");
       _gst_display_oop (oop);
 #endif
 
       _gst_mem.scan.current = oop;
-      _gst_mem.scan.queue_at = QUEUE_NEXT (&_gst_mem.tenuring_queue,
-					   _gst_mem.scan.queue_at + 1);
+      _gst_mem.scan.queue_at++;
 
       if (oop->flags & F_EPHEMERON)
 	continue;
