@@ -30,17 +30,8 @@
  ***********************************************************************/
 
 
-#include "gst.h"
 #include "gstpriv.h"
 
-#include <stdio.h>
-#include <obstack.h>
-
-#if STDC_HEADERS
-#include <stdlib.h>
-#include <string.h>
-#endif /* STDC_HEADERS */
-
 #define	STRING_BASE_SIZE	128
 
 /* This variable holds the base of the buffer maintained by this
