@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002 Free Software Foundation, Inc.
+ * Copyright 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU lightning.
@@ -237,13 +237,13 @@ typedef union jit_code {
 
 /* NTOH/HTON is not mandatory for big endian architectures */
 #ifndef jit_ntoh_ui /* big endian */
-#define jit_ntoh_ui(d, rs)		jit_movr_i((d), (rs))
-#define jit_ntoh_us(d, rs)		jit_movr_i((d), (rs))
+#define jit_ntoh_ui(d, rs)		((d) == (rs) ? (void)0 : jit_movr_i((d), (rs)))
+#define jit_ntoh_us(d, rs)		((d) == (rs) ? (void)0 : jit_movr_i((d), (rs)))
 #endif /* big endian */
 
 /* hton is a synonym for ntoh */
-#define jit_hton_ui(d, rs)		jit_ntoh_i((d), (rs))
-#define jit_hton_us(d, rs)		jit_ntoh_i((d), (rs))
+#define jit_hton_ui(d, rs)		jit_ntoh_ui((d), (rs))
+#define jit_hton_us(d, rs)		jit_ntoh_us((d), (rs))
 
 /* Stack synonyms */
 #define jit_pushr_ui(rs)		jit_pushr_i(rs)
@@ -481,8 +481,8 @@ typedef union jit_code {
 #define jit_movr_l(d, rs)		jit_movr_i((d), (rs))
 
 /* Stack */
-#define jit_push_l(rs)			jit_push_i(rs)
-#define jit_pop_l(rs)			jit_pop_i(rs)		
+#define jit_pushr_l(rs)			jit_pushr_i(rs)
+#define jit_popr_l(rs)			jit_popr_i(rs)		
 #define jit_pusharg_l(rs)		jit_pusharg_i(rs)
 
 /* Memory */
