@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002 Free Software Foundation, Inc.
+ * Copyright 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU lightning.
@@ -304,7 +304,7 @@ struct jit_local_state {
 #define jit_movi_i(d, is)	((is) ? MOVLir((is), (d)) : XORLrr ((d), (d)) )
 
 #define jit_ntoh_ui(d, rs)	jit_op_((d), (rs), BSWAPLr(d))
-#define jit_ntoh_us(d, rs)	jit_op_((d), (rs), RORLir(16, d))
+#define jit_ntoh_us(d, rs)	jit_op_((d), (rs), RORWir(8, d))
 
 /* Boolean */
 #define jit_ltr_i(d, s1, s2)	jit_bool_r((d), (s1), (s2), SETLr(jit_reg8(d))  )
@@ -373,12 +373,12 @@ struct jit_local_state {
 
 /* Memory */
 #define jit_ldi_c(d, is)		jit_movbmr((is), 0,    0,    0, (d), jit_extr_c_i((d), (d)))
-#define jit_ldr_c(d, rs)		jit_movbmr(0,    (rs), 0     0, (d), jit_extr_c_i((d), (d)))
+#define jit_ldr_c(d, rs)		jit_movbmr(0,    (rs), 0,    0, (d), jit_extr_c_i((d), (d)))
 #define jit_ldxr_c(d, s1, s2)		jit_movbmr(0,    (s1), (s2), 1, (d), jit_extr_c_i((d), (d)))
 #define jit_ldxi_c(d, rs, is)		jit_movbmr((is), (rs), 0,    0, (d), jit_extr_c_i((d), (d)))
 
 #define jit_ldi_uc(d, is)		jit_movbmr((is), 0,    0,    0, (d), jit_extr_uc_ui((d), (d)))
-#define jit_ldr_uc(d, rs)		jit_movbmr(0,    (rs), 0     0, (d), jit_extr_uc_ui((d), (d)))
+#define jit_ldr_uc(d, rs)		jit_movbmr(0,    (rs), 0,    0, (d), jit_extr_uc_ui((d), (d)))
 #define jit_ldxr_uc(d, s1, s2)		jit_movbmr(0,    (s1), (s2), 1, (d), jit_extr_uc_ui((d), (d)))
 #define jit_ldxi_uc(d, rs, is)		jit_movbmr((is), (rs), 0,    0, (d), jit_extr_uc_ui((d), (d)))
 
@@ -388,17 +388,17 @@ struct jit_local_state {
 #define jit_stxi_c(id, rd, rs)		jit_movbrm((rs), (id), (rd), 0,    0)
 
 #define jit_ldi_s(d, is)		(MOVWmr((is), 0,    0,    0,  jit_reg16(d)), jit_extr_s_i((d), (d)))
-#define jit_ldr_s(d, rs)		(MOVWmr(0,    (rs), 0     0,  jit_reg16(d)), jit_extr_s_i((d), (d)))
+#define jit_ldr_s(d, rs)		(MOVWmr(0,    (rs), 0,    0,  jit_reg16(d)), jit_extr_s_i((d), (d)))
 #define jit_ldxr_s(d, s1, s2)		(MOVWmr(0,    (s1), (s2), 1,  jit_reg16(d)), jit_extr_s_i((d), (d)))
 #define jit_ldxi_s(d, rs, is)		(MOVWmr((is), (rs), 0,    0,  jit_reg16(d)), jit_extr_s_i((d), (d)))
 
-#define jit_ldi_us(d, is)		(XORrr((d), (d)), MOVWmr((is), 0,    0,    0,  jit_reg16(d)))
-#define jit_ldr_us(d, rs)		(XORrr((d), (d)), MOVWmr(0,    (rs), 0     0,  jit_reg16(d)))
-#define jit_ldxr_us(d, s1, s2)		(XORrr((d), (d)), MOVWmr(0,    (s1), (s2), 1,  jit_reg16(d)))
-#define jit_ldxi_us(d, rs, is)		(XORrr((d), (d)), MOVWmr((is), (rs), 0,    0,  jit_reg16(d)))
+#define jit_ldi_us(d, is)		(XORLrr((d), (d)), MOVWmr((is), 0,    0,    0,  jit_reg16(d)))
+#define jit_ldr_us(d, rs)		(XORLrr((d), (d)), MOVWmr(0,    (rs), 0,    0,  jit_reg16(d)))
+#define jit_ldxr_us(d, s1, s2)		(XORLrr((d), (d)), MOVWmr(0,    (s1), (s2), 1,  jit_reg16(d)))
+#define jit_ldxi_us(d, rs, is)		(XORLrr((d), (d)), MOVWmr((is), (rs), 0,    0,  jit_reg16(d)))
 
 #define jit_sti_s(id, rs)		MOVWrm(jit_reg16(rs), (id), 0,    0,    0)
-#define jit_str_s(rd, rs)		MOVWrm(jit_reg16(rs), 0,    (rd), 0     0)
+#define jit_str_s(rd, rs)		MOVWrm(jit_reg16(rs), 0,    (rd), 0,    0)
 #define jit_stxr_s(d1, d2, rs)		MOVWrm(jit_reg16(rs), 0,    (d1), (d2), 1)
 #define jit_stxi_s(id, rd, rs)		MOVWrm(jit_reg16(rs), (id), (rd), 0,    0)
 
