@@ -1,5 +1,5 @@
 /* Leaving a signal handler executing on the alternate stack.
-   Copyright (C) 2002  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002-2003  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,14 +15,15 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#include "config.h"
-
 #include <stddef.h>
 #include <signal.h>
-#include <sys/signal.h>
+#if HAVE_SYS_SIGNAL_H
+# include <sys/signal.h>
+#endif
 
+/* For MacOSX.  */
 #ifndef SS_ONSTACK
-#define SS_ONSTACK SA_ONSTACK  /* needed for Darwin */
+#define SS_ONSTACK SA_ONSTACK
 #endif
 
 void
