@@ -80,18 +80,18 @@ static intmax_t
 fetch_intmax (struct printf_info *pinfo, union printf_arg const *arg)
 {
   if (pinfo->is_long_double)
-    return (intmax_t) arg->pa_long_long_int;
+    return (intmax_t) (signed long long) arg->pa_long_long_int;
 
   if (pinfo->is_long)
-    return (intmax_t) arg->pa_long_int;
+    return (intmax_t) (signed long) arg->pa_long_int;
 
   if (pinfo->is_short)
-    return (intmax_t) arg->pa_short_int;
+    return (intmax_t) (signed short) arg->pa_short_int;
 
   if (pinfo->is_char)
-    return (intmax_t) arg->pa_char;
+    return (intmax_t) (signed char) arg->pa_char;
 
-  return (intmax_t) arg->pa_int;
+  return (intmax_t) (signed int) arg->pa_int;
 }
 
 static snv_long_double
